###

    DivX SetPassword (npUpload.dll) Denial of Service
    Tested on IE 7 and Divx Player 6.6.0

    Registers:

    EAX 00000000
    ECX FFFFFFFF
    EDX 0191CA50
    EBX 008E06E0
    ESP 0191C9E4
    EBP 0191CA50
    ESI 00000000
    EDI 00000000
    EIP 061F2B52 npUpload.061F2B52

    Access violation when reading [00000000]...

    Discovered by shir, 02/01/2007

    Crash...

# milw0rm.com [2008-01-02]